@@ -173,10 +173,15 @@ class SolgemaFullcalendarView(BrowserView):
     def getCriteriaClass(self):
         anon = self.context.portal_membership.isAnonymousUser()
         listCriteria = self.context.listCriteria()
+        if not listCriteria:
+            return ''
         if listCriteria[0].Field() == 'review_state' and anon:
             return ''
         return self.request.cookies.get('sfqueryDisplay', listCriteria[0].Field())
 
+    def displayNoscriptList(self):
+        return getattr(self.calendar, 'displayNoscriptList', True)
+
 class SolgemaFullcalendarJS(BrowserView):
     """Solgema Fullcalendar Javascript variables"""
 
@@ -326,7 +331,8 @@ class SolgemaFullcalendarEvents(BrowserView):
         response.setHeader('Content-Type', 'application/x-javascript')
         topicCriteria = listQueryTopicCriteria(self.context)
         args = {}
-
+        if not query:
+            return json.dumps([])
         if 'Type' in query.keys():
             items = getCookieItems(self.request, 'Type')
             if items:
