@@ -228,6 +228,11 @@ class ISolgemaFullcalendarProperties(Interface):
                                   description = _(u"help_overrideStateForAdmin"),
                                   default=True)
 
+    displayNoscriptList = schema.Bool( title=_(u"label_displayNoscriptList"),
+                                  required = False,
+                                  description = _(u"help_displayNoscriptList"),
+                                  default=True)
+
     def isSolgemaFullcalendar(self):
         """get name of days"""
 
