@@ -263,12 +263,12 @@ function readCookie(name) {
             width: 600,
             autoOpen: true,
             modal: true,
-            title: fcevent['title'],
+            title: fcevent['title']
           });
           jq('#kss-spinner').hide();
         }
       );
-    },
+    }
   };
 
   jq(document).ready(function() {
@@ -323,6 +323,7 @@ function readCookie(name) {
       editable: true,
       startParam: "start:int",
       endParam: "end:int",
+      ignoreTimezone: false,
       events: "solgemafullcalendarevents",
       axisFormat: SolgemaFullcalendarVars.axisFormat,
       allDaySlot: SolgemaFullcalendarVars.allDaySlot,
@@ -431,3 +432,4 @@ function readCookie(name) {
       }
     });
   });
+
